@@ -309,7 +309,7 @@ Cronk.util.CronkTabHelper = Ext.extend(Object, {
             crname: data.crname,
             closable: true,
             iconCls: data.iconCls || 'icinga-cronk-icon-go-out',
-            
+
             params: {
                 'template': data.template
             }
@@ -323,17 +323,26 @@ Cronk.util.CronkTabHelper = Ext.extend(Object, {
             
             c.store.originParams= {};
             Ext.apply(c.store.originParams,data.cr_base);
-            
-            c.store.groupDir = data.groupDir;
-            c.store.groupField = data.groupField;
-            
-            c.store.sort(data.groupField,data.groupDir);
-            
+
+            if (data.groupDir && data.groupField) {
+                c.store.groupDir = data.groupDir;
+                c.store.groupField = data.groupField;
+                c.store.sort(data.groupField,data.groupDir);
+            }
+            else if (data.sortDir && data.sortField) {
+                c.store.sortDir = data.sortDir;
+                c.store.sortField = data.sortField;
+                c.store.sort(data.sortField,data.sortDir);
+            }
+
             if(p.sort_array)  {
-                p.sort_array[0]['direction'] = data.groupDir;
-                p.sort_array[0]['field'] = data.groupField;
+                p.sort_array[0]['direction'] = data.groupDir || data.sortDir;
+                p.sort_array[0]['field'] = data.groupField || data.sortField;
+            }
+            if(data.filter) {
+                c.filterHdl.updateFromJsonString(data.filter);
+                c.store.setBaseParam("filter_json", Ext.encode(data.filter));
             }
-            
             c.store.load();
             
         });
